# Dataset I/O Library for Review Graph Mining
[![GPLv3](https://img.shields.io/badge/license-GPLv3-blue.svg)](https://www.gnu.org/copyleft/gpl.html)
[![Build Status](https://travis-ci.org/rgmining/dataset-io.svg?branch=master)](https://travis-ci.org/rgmining/dataset-io)
[![wercker status](https://app.wercker.com/status/9fee858cf80340e29b17687c0879fa4f/s/master "wercker status")](https://app.wercker.com/project/byKey/9fee858cf80340e29b17687c0879fa4f)
[![Code Climate](https://codeclimate.com/github/rgmining/dataset-io/badges/gpa.svg)](https://codeclimate.com/github/rgmining/dataset-io)
[![Release](https://img.shields.io/badge/release-0.9.0-brightgreen.svg)](https://github.com/rgmining/dataset-io/releases/tag/v0.9.0)

[![Logo](https://rgmining.github.io/dataset-io/_static/image.png)](https://rgmining.github.io/dataset-io/)

This package defines dataset file format and load/output methods for
[Review Graph Mining Project](https://rgmining.github.io/).
See [documents](https://rgmining.github.io/dataset-io/) for more information.

## Installation
Use `pip` to install this package.

```
pip install --upgrade rgmining-dataset-io
```


## License
This software is released under The GNU General Public License Version 3,
see [COPYING](COPYING) for more detail.
